<p align="center">
<a href="https://artillery.io"><img src="https://artillery.io/img/flag.png" height="55" /></a>
</p>
<p align="center">
<em><strong>Artillery</strong> is a modern, powerful, easy-to-use load-testing toolkit.</em> Artillery has a strong focus on developer happiness &amp; ease of use, and a batteries-included philosophy. Our goal is to help developers build <strong>faster</strong>, more <strong>resilient</strong> and more <strong>scalable</strong> applications.

</p>

## Features

- **Multiple protocols**:  Load test HTTP, WebSocket, Socket.io, Kinesis, HLS and more.
- **Scenarios**: Support for complex *scenarios* to test multi-step interactions in your API or web app (great for ecommerce, transactional APIs, game servers etc).
- **Load testing & Functional testing**: reuse the same scenario definitions to run performance tests or functional tests on your API or backend.
- **Performance metrics**: get detailed performance metrics (latency, requests per second, concurrency, throughput).
- **Scriptable**: write custom logic in JS, using any of the thousands of useful `npm` modules.
- **Integrations**: `statsd` support out of the box for real-time reporting (integrate with [Datadog](http://docs.datadoghq.com/guides/dogstatsd/), [Librato](https://www.librato.com/docs/kb/collect/collection_agents/stastd.html), [InfluxDB](https://influxdata.com/blog/getting-started-with-sending-statsd-metrics-to-telegraf-influxdb/) etc).
- **Extensible**: write custom reporters, custom plugins, custom protocol engines etc.
- **and more!** HTML reports, nice CLI, parameterization with CSV files.

---

- **Source**: [https://github.com/artilleryio/artillery](https://github.com/artilleryio/artillery)
- **Issues**: [https://github.com/artilleryio/artillery/issues](https://github.com/artilleryio/artillery/issues)
- **Chat**: [https://gitter.im/shoreditch-ops/artillery](https://gitter.im/artilleryio/artillery)
- **Community**: [https://spectrum.chat/artillery-io](https://spectrum.chat/artillery-io)
- **Docs**: [https://artillery.io/docs/](https://artillery.io/docs/)
- **Website**: [https://artillery.io](https://artillery.io)
- **Twitter**: [@artilleryio](https://twitter.com/artilleryio)

---

- **Enterprise**: Use [Artillery Pro](https://artillery.io/pro/) to run large-scale distributed tests from your own AWS account, integrate with CI/CD easily, test SOAP services, extra authentication methods (SSL client auth, NTLM).
- For training, custom integrations, and performance consulting services see our [professional services page](https://artillery.io/services-support.html).

[![Build Status](https://travis-ci.org/artilleryio/artillery.svg?branch=master)](https://travis-ci.org/artilleryio/artillery) [![CircleCI](https://circleci.com/gh/artilleryio/artillery.svg?style=svg)](https://circleci.com/gh/artilleryio/artillery)
<a href="https://spectrum.chat/artillery-io"><img src="https://withspectrum.github.io/badge/badge.svg"></a>

# Use Cases

- **Peak traffic testing** - ensure your e-commerce backend, IoT service or web API can handle max traffic
- **Pre-launch load testing** - for new websites, mobile app backends, web APIs etc
- **Continuous performance testing** for new microservices as they are being built
- **Preventing performance regressions** - stop performance regressions due to new code or config changes before they are shipped to users.
- **Help profile & debug** common issues such as extensive GC pauses, memory leaks, improperly configured resource pools etc

# Getting Started With Artillery

👉&nbsp;&nbsp;[Artillery Getting Started Guide](https://artillery.io/docs/getting-started/)

# Using Artillery?

Are you using Artillery to ship faster, more resilient and more scalable systems? Add your team to the [Artillery users list on the wiki](https://github.com/shoreditch-ops/artillery/wiki/Companies-using-Artillery).

# License

**Artillery** is open-source software distributed under the terms of the
[MPLv2](https://www.mozilla.org/en-US/MPL/2.0/) license.

<!--
# Swag

<a href="https://shoreditch-ops.teemill.co.uk/product/artillery-io-hoodie-2976/"><img src="https://shoreditch-ops.teemill.co.uk/uploaded/public/58a0c5f5ce9cd5.85445284.png" alt="artillery.io hoodie" width="180" /></a>

Get some comfy, stylish, and eco-friendly Artillery.io swag from <a href="https://shoreditch-ops.teemill.co.uk/">our shop</a>. All profits go to [Surfers Against Sewage](https://www.sas.org.uk), an environmental charity. 🏄‍
-->
